#define RXD2 4
#define TXD2 2
#define PIN 5
#define RES 19

#include "HX711.h"

// HX711 circuit wiring
const int LOADCELL_DOUT_PIN = 33;
const int LOADCELL_SCK_PIN = 32;

#define RS485_RX 4
#define RS485_TX 2
#define RS485_FC 13

HX711 scale;

void setup() {
  Serial.begin(115200);

  pinMode(RS485_FC, OUTPUT);
  digitalWrite(RS485_FC, HIGH);   // RS-485

  Serial1.begin(9600, SERIAL_8N1, RS485_RX, RS485_TX);
  Serial1.println("RS-485 OK >>>> ");
  delay(500);

  Serial.println("HX711 Demo");
  Serial.println("Initializing the scale");

  // Initialize library with data output pin, clock input pin, and gain factor.
  // Channel selection is made by passing the appropriate gain:
  // - With a gain factor of 64 or 128, channel A is selected
  // - With a gain factor of 32, channel B is selected
  // By omitting the gain factor parameter, the library
  // default "128" (Channel A) is used here.
  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);

  Serial.println("Before setting up the scale:");
  Serial.print("read: \t\t");
  Serial.println(scale.read());            // print a raw reading from the ADC

  Serial.print("read average: \t\t");
  Serial.println(scale.read_average(20));    // print the average of 20 readings from the ADC

  Serial.print("get value: \t\t");
  Serial.println(scale.get_value(5));        // print the average of 5 readings from the ADC minus the tare weight (not set yet)

  Serial.print("get units: \t\t");
  Serial.println(scale.get_units(5), 1);    // print the average of 5 readings from the ADC minus tare weight (not set) divided
  // by the SCALE parameter (not set yet)

  scale.set_scale(2280.f);                      // this value is obtained by calibrating the scale with known weights; see the README for details
  scale.tare();                    // reset the scale to 0

  Serial.println("After setting up the scale:");

  Serial.print("read: \t\t");
  Serial.println(scale.read());                 // print a raw reading from the ADC

  Serial.print("read average: \t\t");
  Serial.println(scale.read_average(20));       // print the average of 20 readings from the ADC

  Serial.print("get value: \t\t");
  Serial.println(scale.get_value(5));        // print the average of 5 readings from the ADC minus the tare weight, set with tare()

  Serial.print("get units: \t\t");
  Serial.println(scale.get_units(5), 1);        // print the average of 5 readings from the ADC minus tare weight, divided
  // by the SCALE parameter set with set_scale

  Serial.println("Readings:");
}

void loop() {
  // Read load cell values
  Serial.print("one reading:\t");
  Serial.print(scale.get_units(), 1);
  Serial.print("\t| average:\t");
  Serial.println(scale.get_units(10), 1);

  // Put the ADC in sleep mode
  scale.power_down();

  // Activate RS-485 communication
  digitalWrite(RS485_FC, HIGH);
  delay(100);
  Serial1.println("RS-485 OK >>>> ");
  delay(100);
  digitalWrite(RS485_FC, LOW);

  // Forward data received on RS-485 to the serial monitor
  while (Serial1.available()) {
    int inByte = Serial1.read();
    Serial.write(inByte);
  }

  // Wake up the ADC
  scale.power_up();

  // Read from port 2 (Serial1), send to port 0 (Serial)
  if (Serial1.available()) {
    int inByte = Serial1.read();
    Serial.write(inByte);
  }

  // Read from port 0 (Serial), send to port 2 (Serial1)
  if (Serial.available()) {
    int inByte = Serial.read();
    Serial1.write(inByte);
  }
}
